Agg class

A helper class to construct aggregations for select clauses.

Constructors

Agg()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

avg(String field, {String? alias}) QueryAggregation
count(String field, {String? alias}) QueryAggregation
max(String field, {String? alias}) QueryAggregation
min(String field, {String? alias}) QueryAggregation
sum(String field, {String? alias}) QueryAggregation