ConfigInfo class

Information about the current effective configuration of the database

Constructors

ConfigInfo({required String dbPath, required String dbName, required String instancePath, required String currentSpaceName, required int userVersion, required int engineVersion, required bool isJournalEnabled, required String encryptionType, required bool isEncryptionEnabled, required int cacheMemoryBudgetMB, required bool isMemoryManaged, required int maxParallelWorkers, required String flushPolicy})
const

Properties

cacheMemoryBudgetMB int
Memory budget for all caches (MB)
final
currentSpaceName String
Current space name
final
dbName String
Database name
final
dbPath String
Root database path
final
encryptionType String
Effective encryption type (none, xor, chacha20, aes256)
final
engineVersion int
Internal engine/storage format version
final
flushPolicy String
Current storage flush policy (adaptive, low, medium, high, off)
final
hashCode int
The hash code for this object.
no setterinherited
instancePath String
Absolute path to the database instance directory
final
isEncryptionEnabled bool
Whether data encryption is currently active
final
isJournalEnabled bool
Whether write-ahead logging (WAL) is enabled
final
isMemoryManaged bool
Whether memory manager is initialized
final
maxParallelWorkers int
Maximum number of parallel workers (isolates)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userVersion int
Current business version (set by the developer via setVersion)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited