ExprNode class abstract

Base class for all expression nodes in the expression AST.

This type-safe system prevents injection attacks by disallowing arbitrary string expressions and only allowing structured, validated operations.

All expressions are evaluated atomically using current field values from the record at update time, preventing race conditions.

Implementers
Available extensions

Constructors

ExprNode()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator %(ExprNode other) BinaryOp

Available on ExprNode, provided by the ExprNodeOperators extension

Modulo operator: this % other
operator *(ExprNode other) BinaryOp

Available on ExprNode, provided by the ExprNodeOperators extension

Multiplication operator: this * other
operator +(ExprNode other) BinaryOp

Available on ExprNode, provided by the ExprNodeOperators extension

Addition operator: this + other
operator -(ExprNode other) BinaryOp

Available on ExprNode, provided by the ExprNodeOperators extension

Subtraction operator: this - other
operator /(ExprNode other) BinaryOp

Available on ExprNode, provided by the ExprNodeOperators extension

Division operator: this / other
operator ==(Object other) bool
The equality operator.
inherited
operator unary-() UnaryOp

Available on ExprNode, provided by the ExprNodeOperators extension

Unary negation operator: -this