MigrationTask class

migration task, for storing table structure, table data migration operations

Constructors

MigrationTask({required String taskId, required String tableName, required bool isSchemaUpdated, required List<String> pendingMigrationSpaces, required List<MigrationOperation> operations, required DateTime createTime, required int dirIndex, bool isAutoGenerated = false, TableSchema? oldSchemaSnapshot})
const
MigrationTask.fromJson(Map<String, dynamic> json)
create from json
factory

Properties

createTime DateTime
final
dirIndex int
final
hashCode int
The hash code for this object.
no setterinherited
isAutoGenerated bool
final
isSchemaUpdated bool
final
oldSchemaSnapshot TableSchema?
final
operations List<MigrationOperation>
final
pendingMigrationSpaces List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableName String
final
taskId String
final

Methods

addPendingSpace(String space) MigrationTask
add a single pending migration space
copyWith({String? taskId, String? tableName, bool? isSchemaUpdated, List<String>? pendingMigrationSpaces, List<MigrationOperation>? operations, DateTime? createTime, int? dirIndex, bool? isAutoGenerated, TableSchema? oldSchemaSnapshot}) MigrationTask
create a copy (basic method)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removePendingSpace(String space) MigrationTask
remove a single pending migration space
setSchemaUpdated(bool updated) MigrationTask
set the table structure change status
toJson() Map<String, dynamic>
convert to json
toString() String
A string representation of this object.
inherited
updatePendingSpaces(List<String> spaces) MigrationTask
update the pending migration spaces

Operators

operator ==(Object other) bool
The equality operator.
inherited