SequentialIdConfig class

Sequential primary key configuration

Constructors

SequentialIdConfig({int initialValue = 1, int increment = 1, bool useRandomIncrement = false})
const
SequentialIdConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
increment int
Increment step
final
initialValue int
Initial increment value
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useRandomIncrement bool
Whether to enable random step (1 to increment)
final

Methods

copyWith({int? initialValue, int? increment, bool? useRandomIncrement}) SequentialIdConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited