instancePath property
String?
get
instancePath
Get the final storage path of the database instance.
获取数据库实例最终存储目录的完整路径。
Implementation
String? get instancePath => _impl.instancePath;
Get the final storage path of the database instance.
获取数据库实例最终存储目录的完整路径。
String? get instancePath => _impl.instancePath;