tableExists method

  1. @override
Future<bool> tableExists(
  1. String tableName
)

Check if a table has been defined in the current database (space‑agnostic).

This method only checks whether the table structure exists and can be used, not whether the table contains any rows.

tableName The name of the table to check. Returns true if the table structure exists.

检查当前数据库中是否已经存在指定表的结构定义(与 Space 无关),仅代表该表可以被使用, 不代表表中是否已有数据。

tableName 要检查的表名。 如果表结构存在则返回 true。

Implementation

@override
Future<bool> tableExists(String tableName) async {
  return await _impl.tableExists(tableName);
}