TransactionError class

Transaction error (public API)

Provides transaction-level error summary, without the details of each operation.

Constructors

TransactionError({required TransactionErrorType type, required String message, Object? cause, String? stackTrace})
const

Properties

cause Object?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace String?
final
type TransactionErrorType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited