VectorPrecision enum

Vector precision options

Specifies the numeric precision used for storing vector values. Higher precision offers better accuracy but uses more storage space.

Inheritance
Available extensions

Values

float64 → const VectorPrecision

64-bit floating point (IEEE 754)

Default and highest precision, uses 8 bytes per dimension

float32 → const VectorPrecision

32-bit floating point

Standard single precision, uses 4 bytes per dimension Offers a good balance between precision and storage efficiency

int8 → const VectorPrecision

8-bit integer (quantized)

Uses quantization to reduce storage to 1 byte per dimension Significant memory savings with some loss of precision

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VectorPrecision>
A constant List of the values in this enum, in order of their declaration.