DbStatus class abstract
Database status and diagnostics interface
Constructors
- DbStatus()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
config(
) → Future< ConfigInfo> - Get effective configuration status
-
memory(
) → Future< MemoryInfo> - Get internal memory and cache status
-
migration(
String taskId) → Future< MigrationStatus?> - Get migration task status
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
space(
{bool useCache = true}) → Future< SpaceInfo> -
Get space-wide storage statistics (record count, data size, tables list)
useCacheWhether to use cached data. Defaults to true. -
table(
String tableName) → Future< TableInfo?> - Get specific table information
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited