FieldSchemaUpdate class
model for field update, allow explicit distinction of whether a value is set
Constructors
- FieldSchemaUpdate({required String name, DataType? type, bool? nullable, dynamic defaultValue, bool? unique, String? comment, int? minLength, int? maxLength, num? minValue, num? maxValue, DefaultValueType? defaultValueType, String? fieldId, VectorFieldConfig? vectorConfig})
-
FieldSchemaUpdate.fromJson(Map<
String, dynamic> json) -
factory
-
FieldSchemaUpdate.rehydrate({required String name, DataType? type, bool? nullable, dynamic defaultValue, bool? unique, String? comment, int? minLength, int? maxLength, num? minValue, num? maxValue, DefaultValueType? defaultValueType, String? fieldId, VectorFieldConfig? vectorConfig, Map<
String, bool> ? explicitlySet}) -
Reconstruct from binary codec with explicit-set flags.
factory
Properties
- comment → String?
-
final
- defaultValue → dynamic
-
final
- defaultValueType → DefaultValueType?
-
final
-
explicitlySetFlags
→ Map<
String, bool> -
Engine/codec: which properties were explicitly set (including nulls).
no setter
- fieldId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLength → int?
-
final
- maxValue → num?
-
final
- minLength → int?
-
final
- minValue → num?
-
final
- name → String
-
final
- nullable → bool?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DataType?
-
final
- unique → bool?
-
final
- vectorConfig → VectorFieldConfig?
-
final
Methods
-
copyWithName(
String newName) → FieldSchemaUpdate - Create a copy of this update with a different name
-
isExplicitlySet(
String propertyName) → bool - check if the property is explicitly set
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited