QueryAggregator class

Constructors

QueryAggregator(List<QueryAggregation> aggregations, {List<String>? groupBy})

Properties

aggregations List<QueryAggregation>
final
groupBy List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
result → dynamic
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accumulate(Map<String, dynamic> row) → void
getGroupedResults() List<Map<String, dynamic>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited