SpaceInfo class
Information about a space in the database
Constructors
Properties
- dataSizeBytes → int
-
Total data size in bytes
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastStatisticsTime → DateTime?
-
Last time statistics were updated
final
- recordCount → int
-
Total number of records across all tables in this space
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spaceName → String
-
Name of the space
final
- tableCount → int
-
Number of user-created tables in this space
final
-
tables
→ List<
String> -
User-created tables available in this space
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Create a map representation of this object
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited