UnaryOp class
Represents a unary operation (e.g., negation, absolute value).
- Inheritance
- Available extensions
Constructors
- UnaryOp(UnaryOperator op, ExprNode operand)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- op → UnaryOperator
-
The operator type
final
- operand → ExprNode
-
The operand
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator %(
ExprNode other) → BinaryOp -
Available on ExprNode, provided by the ExprNodeOperators extension
Modulo operator: this % other -
operator *(
ExprNode other) → BinaryOp -
Available on ExprNode, provided by the ExprNodeOperators extension
Multiplication operator: this * other -
operator +(
ExprNode other) → BinaryOp -
Available on ExprNode, provided by the ExprNodeOperators extension
Addition operator: this + other -
operator -(
ExprNode other) → BinaryOp -
Available on ExprNode, provided by the ExprNodeOperators extension
Subtraction operator: this - other -
operator /(
ExprNode other) → BinaryOp -
Available on ExprNode, provided by the ExprNodeOperators extension
Division operator: this / other -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator unary-(
) → UnaryOp -
Available on ExprNode, provided by the ExprNodeOperators extension
Unary negation operator: -this